package babase.ranker;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JTextArea;

public class AboutUI extends JFrame {
    
    private static final long serialVersionUID = 1L;

    public AboutUI() {

        setTitle("About Babase Ranker");
        setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);

        JTextArea textArea = new JTextArea();
        textArea.append("Babase Ranker v1.3\n");
        textArea.append("v1.3 by Jake Gordon <jacob.gordon@duke.edu>\n");
        textArea.append("v1.1, v1.2, v1.2.1 by Karl O. Pinc <kop@meme.com>\n");
        textArea.append("v1.0 by Jun Yang\n");
        textArea.append("v0.9 by Tyler Brock and Jun Yang\n");
        textArea.append("Initial Java version by Jun Yang\n");
        textArea.append("Original FoxPro version by Karl O. Pinc\n");        

        JButton okButton = new JButton("OK");
        okButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                setVisible(false);
                return;
            }
        });
        
        getContentPane().setLayout(new BorderLayout());
        getContentPane().add(textArea, BorderLayout.CENTER);
        getContentPane().add(okButton, BorderLayout.SOUTH);

        setResizable(false);
        pack();
        setLocationRelativeTo(null);
        return;
    }
    
}
